@@ -1,12 +1,25 @@
 //-----------------------------------------------------------------------------
-// Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
-// This program is free software: you can modify it and/or redistribute it
-// under the terms of:
+// Copyright (c) 2016, 2024, Oracle and/or its affiliates.
 //
-// (i)  the Universal Permissive License v 1.0 or at your option, any
-//      later version (http://oss.oracle.com/licenses/upl); and/or
+// This software is dual-licensed to you under the Universal Permissive License
+// (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
+// 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose
+// either license.
 //
-// (ii) the Apache License v 2.0. (http://www.apache.org/licenses/LICENSE-2.0)
+// If you elect to accept the software under the Apache License, Version 2.0,
+// the following applies:
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//    https://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 //-----------------------------------------------------------------------------
 
 //-----------------------------------------------------------------------------
@@ -38,8 +51,6 @@ int dpiLob__allocate(dpiConn *conn, const dpiOracleType *type, dpiLob **lob,
     }
     if (dpiHandleList__addHandle(conn->openLobs, tempLob,
             &tempLob->openSlotNum, error) < 0) {
-        dpiOci__descriptorFree(tempLob->locator, DPI_OCI_DTYPE_LOB);
-        tempLob->locator = NULL;
         dpiLob__free(tempLob, error);
         return DPI_FAILURE;
     }
@@ -57,8 +68,10 @@ static int dpiLob__check(dpiLob *lob, const char *fnName, dpiError *error)
 {
     if (dpiGen__startPublicFn(lob, DPI_HTYPE_LOB, fnName, error) < 0)
         return DPI_FAILURE;
+    if (!lob->conn || !lob->conn->handle)
+        return dpiError__set(error, "conn closed?", DPI_ERR_NOT_CONNECTED);
     if (!lob->locator)
-        return dpiError__set(error, "check closed", DPI_ERR_LOB_CLOSED);
+        return dpiError__set(error, "LOB closed?", DPI_ERR_LOB_CLOSED);
     return dpiConn__checkConnected(lob->conn, error);
 }
 
@@ -95,8 +108,6 @@ int dpiLob__close(dpiLob *lob, int propagateErrors, dpiError *error)
                         lob->locator, propagateErrors, error);
         }
         dpiOci__descriptorFree(lob->locator, DPI_OCI_DTYPE_LOB);
-        if (!lob->conn->closing)
-            dpiHandleList__removeHandle(lob->conn->openLobs, lob->openSlotNum);
         lob->locator = NULL;
     }
     if (lob->buffer) {
@@ -127,6 +138,7 @@ void dpiLob__free(dpiLob *lob, dpiError *error)
 {
     dpiLob__close(lob, 0, error);
     if (lob->conn) {
+        dpiHandleList__removeHandle(lob->conn->openLobs, lob->openSlotNum);
         dpiGen__setRefCount(lob->conn, error, -1);
         lob->conn = NULL;
     }
