@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-// Copyright (c) 2016, 2022, Oracle and/or its affiliates.
+// Copyright (c) 2016, 2024, Oracle and/or its affiliates.
 //
 // This software is dual-licensed to you under the Universal Permissive License
 // (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
@@ -344,6 +344,26 @@ static const dpiOracleType
         0,                                  // can be in array
         0                                   // requires pre-fetch
     },
+    {
+        DPI_ORACLE_TYPE_XMLTYPE,            // public Oracle type
+        DPI_NATIVE_TYPE_BYTES,              // default native type
+        DPI_SQLT_CHR,                       // internal Oracle type
+        DPI_SQLCS_IMPLICIT,                 // charset form
+        DPI_MAX_BASIC_BUFFER_SIZE + 1,      // buffer size
+        1,                                  // is character data
+        0,                                  // can be in array
+        0                                   // requires pre-fetch
+    },
+    {
+        DPI_ORACLE_TYPE_VECTOR,             // public Oracle type
+        DPI_NATIVE_TYPE_VECTOR,             // default native type
+        DPI_SQLT_VEC,                       // internal Oracle type
+        DPI_SQLCS_IMPLICIT,                 // charset form
+        sizeof(void*),                      // buffer size
+        0,                                  // is character data
+        0,                                  // can be in array
+        1                                   // requires pre-fetch
+    },
 };
 
 
@@ -425,6 +445,8 @@ static dpiOracleTypeNum dpiOracleType__convertFromOracle(uint16_t typeCode,
             return DPI_ORACLE_TYPE_LONG_RAW;
         case DPI_SQLT_JSON:
             return DPI_ORACLE_TYPE_JSON;
+        case DPI_SQLT_VEC:
+            return DPI_ORACLE_TYPE_VECTOR;
     }
     return (dpiOracleTypeNum) 0;
 }
@@ -454,10 +476,12 @@ const dpiOracleType *dpiOracleType__getFromNum(dpiOracleTypeNum typeNum,
 int dpiOracleType__populateTypeInfo(dpiConn *conn, void *handle,
         uint32_t handleType, dpiDataTypeInfo *info, dpiError *error)
 {
+    uint32_t dataTypeAttribute, i, tempFlags;
     const dpiOracleType *oracleType = NULL;
+    uint8_t charsetForm, isJson, isOson;
     dpiNativeTypeNum nativeTypeNum;
-    uint32_t dataTypeAttribute;
-    uint8_t charsetForm;
+    void *listParam, *itemParam;
+    dpiAnnotation *annotation;
     uint16_t ociSize;
 
     // acquire data type
@@ -560,10 +584,112 @@ int dpiOracleType__populateTypeInfo(dpiConn *conn, void *handle,
             dpiObjectType__free(info->objectType, error);
             info->objectType = NULL;
             info->ociTypeCode = DPI_SQLT_CHR;
-            info->oracleTypeNum = DPI_ORACLE_TYPE_LONG_VARCHAR;
+            info->oracleTypeNum = DPI_ORACLE_TYPE_XMLTYPE;
             info->defaultNativeTypeNum = DPI_NATIVE_TYPE_BYTES;
         }
     }
 
+    // determine if the data refers to a JSON column
+    if (handleType == DPI_OCI_HTYPE_DESCRIBE &&
+            conn->env->versionInfo->versionNum >= 19) {
+        if (dpiOci__attrGet(handle, handleType, (void*) &isJson, 0,
+                DPI_OCI_ATTR_JSON_COL, "get is JSON column", error) < 0)
+            return DPI_FAILURE;
+        info->isJson = isJson;
+    }
+
+    // determine if the data refers to an OSON column
+    if (handleType == DPI_OCI_HTYPE_DESCRIBE &&
+            conn->env->versionInfo->versionNum >= 21) {
+        if (dpiOci__attrGet(handle, handleType, (void*) &isOson, 0,
+                DPI_OCI_ATTR_OSON_COL, "get is OSON column", error) < 0)
+            return DPI_FAILURE;
+        info->isOson = isOson;
+    }
+
+    // get domain and annotations, if applicable
+    if (handleType == DPI_OCI_HTYPE_DESCRIBE &&
+            conn->env->versionInfo->versionNum >= 23) {
+
+        // check for domain
+        if (dpiOci__attrGet(handle, handleType, (void*) &info->domainSchema,
+                &info->domainSchemaLength, DPI_OCI_ATTR_DOMAIN_SCHEMA,
+                "get domain schema", error) < 0)
+            return DPI_FAILURE;
+        if (dpiOci__attrGet(handle, handleType, (void*) &info->domainName,
+                &info->domainNameLength, DPI_OCI_ATTR_DOMAIN_NAME,
+                "get domain name", error) < 0)
+            return DPI_FAILURE;
+
+        // check for annotations
+        if (dpiOci__attrGet(handle, handleType, (void*) &info->numAnnotations,
+                0, DPI_OCI_ATTR_NUM_ANNOTATIONS, "get number of annotations",
+                error) < 0)
+            return DPI_FAILURE;
+        if (info->numAnnotations > 0) {
+
+            // allocate memory for the array
+            if (dpiUtils__allocateMemory(info->numAnnotations,
+                    sizeof(dpiAnnotation), 1, "allocate annotation array",
+                    (void**) &info->annotations, error) < 0)
+                return DPI_FAILURE;
+
+            // get the list parameter
+            if (dpiOci__attrGet(handle, handleType,
+                    (void*) &listParam, 0, DPI_OCI_ATTR_LIST_ANNOTATIONS,
+                    "get annotation list param", error) < 0)
+                return DPI_FAILURE;
+
+            // populate the arrays
+            for (i = 0 ; i < info->numAnnotations; i++) {
+                annotation = &info->annotations[i];
+                if (dpiOci__paramGet(listParam, DPI_OCI_DTYPE_PARAM,
+                        &itemParam, (uint32_t) i + 1, "get annotation",
+                        error) < 0)
+                    return DPI_FAILURE;
+                if (dpiOci__attrGet(itemParam, DPI_OCI_DTYPE_PARAM,
+                        (void*) &annotation->key, &annotation->keyLength,
+                        DPI_OCI_ATTR_ANNOTATION_KEY,
+                        "get annotation key", error) < 0)
+                    return DPI_FAILURE;
+                if (dpiOci__attrGet(itemParam, DPI_OCI_DTYPE_PARAM,
+                        (void*) &annotation->value, &annotation->valueLength,
+                        DPI_OCI_ATTR_ANNOTATION_VALUE,
+                        "get annotation value", error) < 0)
+                    return DPI_FAILURE;
+            }
+
+        }
+
+    }
+
+    // get vector metadata, if applicable
+    if (info->oracleTypeNum == DPI_ORACLE_TYPE_VECTOR) {
+
+        // get vector format
+        if (dpiOci__attrGet(handle, handleType, &info->vectorFormat, 0,
+                DPI_OCI_ATTR_VECTOR_DATA_FORMAT, "get vector column format",
+                error) < 0)
+            return DPI_FAILURE;
+
+        // get number of dimensions
+        if (dpiOci__attrGet(handle, handleType, &info->vectorDimensions, 0,
+                DPI_OCI_ATTR_VECTOR_DIMENSION,
+                "get number of vector dimensions in column", error) < 0)
+            return DPI_FAILURE;
+
+        // get vector column flags
+        // NOTE: all of the values for the vector column flags fit within a
+        // single byte, but the Oracle Client libraries still expect a pointer
+        // to a four byte value and failing to do so causes a segfault on some
+        // platforms
+        if (dpiOci__attrGet(handle, handleType, &tempFlags, 0,
+                DPI_OCI_ATTR_VECTOR_PROPERTY, "get vector column flags",
+                error) < 0)
+            return DPI_FAILURE;
+        info->vectorFlags = (uint8_t) tempFlags;
+
+    }
+
     return DPI_SUCCESS;
 }
